@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Fatal;
 {
-  $Test::Fatal::VERSION = '0.009';
+  $Test::Fatal::VERSION = '0.011';
 }
 # ABSTRACT: incredibly simple helpers for testing code with exceptions
 
@@ -16,10 +16,32 @@ our @EXPORT    = qw(exception);
 our @EXPORT_OK = qw(exception success dies_ok lives_ok);
 
 
+our ($REAL_TBL, $REAL_CALCULATED_TBL) = (1, 1);
+
 sub exception (&) {
   my $code = shift;
 
   return try {
+    my $incremented = $Test::Builder::Level - $REAL_CALCULATED_TBL;
+    local $Test::Builder::Level = $REAL_CALCULATED_TBL;
+    if ($incremented) {
+        # each call to exception adds 5 stack frames
+        $Test::Builder::Level += 5;
+        for my $i (1..$incremented) {
+            # -2 because we want to see it from the perspective of the call to
+            # is() within the call to $code->()
+            my $caller = caller($Test::Builder::Level - 2);
+            if ($caller eq __PACKAGE__) {
+                # each call to exception adds 5 stack frames
+                $Test::Builder::Level = $Test::Builder::Level + 5;
+            }
+            else {
+                $Test::Builder::Level = $Test::Builder::Level + 1;
+            }
+        }
+    }
+
+    local $REAL_CALCULATED_TBL = $Test::Builder::Level;
     $code->();
     return undef;
   } catch {
@@ -70,6 +92,7 @@ sub lives_ok (&;$) {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -78,7 +101,7 @@ Test::Fatal - incredibly simple helpers for testing code with exceptions
 
 =head1 VERSION
 
-version 0.009
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -142,14 +165,19 @@ C<Sub::Uplevel> mechanism.
 
 B<Achtung!>  This is not a great idea:
 
-  like( exception { ... }, qr/foo/, "foo appears in the exception" );
+  sub exception_like(&$;$) {
+      my ($code, $pattern, $name) = @_;
+      like( &exception($code), $pattern, $name );
+  }
+
+  exception_like(sub { }, qr/foo/, 'foo appears in the exception');
 
 If the code in the C<...> is going to throw a stack trace with the arguments to
-each subroutine in its call stack, the test name, "foo appears in the
-exception" will itself be matched by the regex.  Instead, write this:
+each subroutine in its call stack (for example via C<Carp::confess>,
+the test name, "foo appears in the exception" will itself be matched by the
+regex.  Instead, write this:
 
-  my $exception = exception { ... };
-  like( $exception, qr/foo/, "foo appears in the exception" );
+  like( exception { ... }, qr/foo/, 'foo appears in the exception' );
 
 B<Achtung>: One final bad idea:
 
@@ -210,4 +238,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
